summaryrefslogtreecommitdiff
path: root/Master/setuptl/TLPM
diff options
context:
space:
mode:
Diffstat (limited to 'Master/setuptl/TLPM')
-rw-r--r--Master/setuptl/TLPM/blng.pm4
-rw-r--r--Master/setuptl/TLPM/check.pm4
-rw-r--r--Master/setuptl/TLPM/cmdl.pm6
-rw-r--r--Master/setuptl/TLPM/common.pm4
-rw-r--r--Master/setuptl/TLPM/constants.pm4
-rw-r--r--Master/setuptl/TLPM/help.pm88
-rw-r--r--Master/setuptl/TLPM/incl.pm4
-rw-r--r--Master/setuptl/TLPM/info.pm4
-rw-r--r--Master/setuptl/TLPM/inst.pm4
-rw-r--r--Master/setuptl/TLPM/list.pm2
-rw-r--r--Master/setuptl/TLPM/pkg.pm8
-rw-r--r--Master/setuptl/TLPM/reg.pm2
-rw-r--r--Master/setuptl/TLPM/uninst.pm2
13 files changed, 73 insertions, 63 deletions
diff --git a/Master/setuptl/TLPM/blng.pm b/Master/setuptl/TLPM/blng.pm
index 5743fdda2c4..f8940cc5705 100644
--- a/Master/setuptl/TLPM/blng.pm
+++ b/Master/setuptl/TLPM/blng.pm
@@ -1,8 +1,8 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# blng [-pf] <name>
-# display which package belongs to one given
+# display packages containing <name> (to which the <name> belongs to)
sub blng
{
diff --git a/Master/setuptl/TLPM/check.pm b/Master/setuptl/TLPM/check.pm
index 9000369dd3b..b5273b8cd31 100644
--- a/Master/setuptl/TLPM/check.pm
+++ b/Master/setuptl/TLPM/check.pm
@@ -1,8 +1,8 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# check [-pf]
-# check the installation consistency
+# check the existence of files and packages
sub check
{
diff --git a/Master/setuptl/TLPM/cmdl.pm b/Master/setuptl/TLPM/cmdl.pm
index 141e7b1a9e3..b654736c471 100644
--- a/Master/setuptl/TLPM/cmdl.pm
+++ b/Master/setuptl/TLPM/cmdl.pm
@@ -1,10 +1,10 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# cmdline parsing
-# surely we can't rely on windows shell behaviour, so we make all the parsing.
-# some day I'd like to use native shell for u*x though...
+# since I can't rely on windows shell behaviour, I make all the parsing
+# on my own. some day I'd like to use native shell for u*x though...
sub resolve_env # resolve environment variables
{
diff --git a/Master/setuptl/TLPM/common.pm b/Master/setuptl/TLPM/common.pm
index b1cd93a09a6..9f7770baa65 100644
--- a/Master/setuptl/TLPM/common.pm
+++ b/Master/setuptl/TLPM/common.pm
@@ -1,10 +1,10 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# common procedures;
# to avoid any stdlib dependencies, we implement a couple of trivial procedures here
-# trivial operations on paths
+# operations on paths
sub dirsep2dirsep
{
diff --git a/Master/setuptl/TLPM/constants.pm b/Master/setuptl/TLPM/constants.pm
index 532f81ca13e..6359e84cb05 100644
--- a/Master/setuptl/TLPM/constants.pm
+++ b/Master/setuptl/TLPM/constants.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# widely used constants
@@ -34,7 +34,7 @@ $parent_dir = &rel2abs('..',$curr_dir);
# tlpm related constants
-$tlpm_prompt = "tlpm>";
+$tlpm_prompt = "tlpm" . $tlpm_version . ">";
$tlpm_log = $chr_dirsep . "tlpm.log"; # log file
$tlpm_dbg = $chr_dirsep . "tlpm.debug"; # debug file
diff --git a/Master/setuptl/TLPM/incl.pm b/Master/setuptl/TLPM/incl.pm
index a86c20eab39..909f0a6d069 100644
--- a/Master/setuptl/TLPM/incl.pm
+++ b/Master/setuptl/TLPM/incl.pm
@@ -1,8 +1,8 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# incl <pkg> [-pfer] <mask>
-# display a list of included packages matching <mask>
+# display a list of packages included in <pkg> and matching <mask>
sub incl
{
diff --git a/Master/setuptl/TLPM/info.pm b/Master/setuptl/TLPM/info.pm
index 324d1a68a32..7bafa216191 100644
--- a/Master/setuptl/TLPM/info.pm
+++ b/Master/setuptl/TLPM/info.pm
@@ -1,8 +1,8 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# info <pkg>
-# retrieve package info from tpm file
+# retrieve package info from .tpm file
sub info
{
diff --git a/Master/setuptl/TLPM/inst.pm b/Master/setuptl/TLPM/inst.pm
index 757ebbedb59..896d50e8ad3 100644
--- a/Master/setuptl/TLPM/inst.pm
+++ b/Master/setuptl/TLPM/inst.pm
@@ -1,8 +1,8 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# inst <pkg> [-jrou]
-# install <pkg>
+# install <pkg> respecting dependencies
sub inst
{
diff --git a/Master/setuptl/TLPM/list.pm b/Master/setuptl/TLPM/list.pm
index c110b487542..3a8d24bfcdf 100644
--- a/Master/setuptl/TLPM/list.pm
+++ b/Master/setuptl/TLPM/list.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# list [-pfe] <mask>
diff --git a/Master/setuptl/TLPM/pkg.pm b/Master/setuptl/TLPM/pkg.pm
index b3e53ac200c..def04a44d21 100644
--- a/Master/setuptl/TLPM/pkg.pm
+++ b/Master/setuptl/TLPM/pkg.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# reading packages (internal functions)
@@ -14,8 +14,8 @@ $target_pkges = \%target_packages;
sub read_pkges # used for reading both source and target packages
{
my ($dir,$pkges) = @_; # <root_directory> <hash_reference>
- # Staszek Wawrykiewicz reports that the condition '-d E:' doesn't work in some cases.
- # Not reproduced... However, '-d X:\texmf' works fine, so
+ # StaW reports that the condition alike '-d E:' doesn't work in some cases.
+ # Not reproduced... However, '-d E:\texmf' works fine, so
unless(-d $dir || -d "$dir$tl_texmf")
{
return $error{'miss_dir'} -> ($dir);
@@ -29,7 +29,7 @@ sub read_pkges # used for reading both source and target packages
local (*DIR,*INP);
$message -> ("Reading packages from '$dir'...");
opendir(DIR,$dir) or return $error{'cant_odir'} -> ($dir);
- readdir DIR; readdir DIR; # remove '.' and '..'; dirty but works and make things faster
+ readdir DIR; readdir DIR; # remove '.' and '..'; dirty but works and make things a bit faster
foreach $pkg (readdir DIR)
{
($pcount,$fcount) = (0,0);
diff --git a/Master/setuptl/TLPM/reg.pm b/Master/setuptl/TLPM/reg.pm
index 19c7081ab13..ce59a7f27a6 100644
--- a/Master/setuptl/TLPM/reg.pm
+++ b/Master/setuptl/TLPM/reg.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# regexpresions and masks related functions
diff --git a/Master/setuptl/TLPM/uninst.pm b/Master/setuptl/TLPM/uninst.pm
index 8c2697d6095..b70982465ad 100644
--- a/Master/setuptl/TLPM/uninst.pm
+++ b/Master/setuptl/TLPM/uninst.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# uninst <pkg> [-rjF] [dir]
diff --git a/Master/setuptl/TLPM/help.pm b/Master/setuptl/TLPM/help.pm
index 25fc1a2c754..ec3b0a45b6e 100644
--- a/Master/setuptl/TLPM/help.pm
+++ b/Master/setuptl/TLPM/help.pm
@@ -1,4 +1,4 @@
# This file belongs to TLPM v2.14, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# help
@@ -37,37 +37,40 @@ Public Domain, P.Jackowski\@gust.org.pl",
'technical_notes' => "TECHNICAL NOTES:
* About TLPM
-TLPM (TeX Live Package Manager) helps to search, trace dependencies, and install
-TeX Live packages. It works with TeX Live 2004-2006. Initially, TLPM was a Perl script
-just for controlling the mass of TeX Live packages repository. Since there were no
-win-installer on TeX Live 2004, TLPM became a rescue solution. Starting from version 2.11,
-TLPM works, with some restrictions, under Unix shells as well.
-
-Since there is no consistent versioning system withing TeX Live distribution, TLPM does
-NOT support upgrades or downgrades. TLPM fully relies on the information retrieved from
-the TPM files (actually from text files stored in the 'texmf/lists' directory). If you don't
-trust TPMs, do NOT trust TLPM either!
-
-All the configuration is beyond the scope of TLPM functionality. TLPM doesn't perform
-any post-installation actions such as setting of environment variables, building formats
-or updating fontmap files. All those tasks are made by TLPMGUI program written
-by Tomek \\{}Luczak.
+TLPM (TeX Live Package Manager) helps to search, trace dependencies, and
+install TeX Live packages. It works with TeX Live 2004-2006. Initially, TLPM
+was just my private Perl script for controlling the mass of TeX Live packages
+repository. Since there were no win-installer on TeX Live 2004, TLPM became a
+rescue solution. Starting from version 2.11, TLPM works, with some
+restrictions, under Unix shells as well.
+
+Since there is no consistent versioning system withing TeX Live distribution,
+TLPM does NOT support upgrades or downgrades, neither of packages, nor of the
+entire distribution. TLPM fully relies on the information retrieved from the
+TPM files (actually from text files stored in the 'texmf/lists' directory).
+If you don't trust TPMs, do NOT trust TLPM either!
+
+All the configuration is beyond the scope of TLPM functionality. TLPM doesn't
+perform any post-installation actions such as setting of environment
+variables, building formats or updating fontmap files. All those actions are
+accomplished by a pretty nice TLPMGUI front-end written by Tomek \\{}Luczak.
* Usage
-TLPM tries to detect the CD/DVD drive with TeX Live disk automagically. If the magic
-fails, TLPM prompts to provide a mounting point, unless one use the '--source'
-command-line option or the 'tl_source' environment variable (which might be useful
-while installing from local hard drive resources).
-
-The target installation directory can be specified with the '--directory' command-line
-option or the 'tl_target' environment variable. If both are missing, one is prompted
-for the target directory during runtime (interactive mode) or it is initialized
-to current directory (batch mode).
-
-TLPM can be run in batch mode. In such a case, each line of the batch file
-is treated as a TLPM command, unless empty or starts with the '%' or '#' characters.
-The range of commands and options available in batch mode is the same as in
-the interactive mode. Mentioned TLPMGUI program communicates with TLPM via batches.
+TLPM tries to detect the CD/DVD drive with TeX Live disk automagically. If
+the magic fails, TLPM prompts to provide a mounting point, unless one use the
+'--source' command-line option or the 'tl_source' environment variable (which
+might be useful while installing from local hard drive resources).
+
+The target installation directory can be specified with the '--directory'
+command-line option or the 'tl_target' environment variable. If both are
+missing, one is prompted for the target directory during runtime (interactive
+mode) or it is initialized to current directory (batch mode).
+
+TLPM can be run in batch mode. In such a case, each line of the batch file is
+treated as a TLPM command, unless empty or starts with the '%' or '#'
+characters. The range of commands and options available in batch mode is the
+same as in the interactive mode. Mentioned TLPMGUI program communicates with
+TLPM via batches.
The history of installed and uninstalled packages is saved in the tlpm.log file
stored in the TeX Live target directory. TLPM does not reuse this file and
@@ -81,16 +84,19 @@ line. Quotation is necessary while using path names with spaces (strongly not
recommended!) or other strange characters that may conflict with the command
syntax. If so, please quote the entire phrase. Whenever analysing the command,
TLPM also resolves environment variables expressed as '%variable%' or '\$variable'.
-Shell specific expansions are not performed.
+
+To ensure possibly similar behaviour for different platforms, TLPM interprets
+all the command line (including '>file' and '|stream' redirection) on its
+own. Hence, some shell specific expansion may not work as normally expected.
* License
I have done my best to make TLPM functional and reliable, but can NOT warrant
-anything. If you like TLPM, feel free to redistribute it without any restrictions.
-TLPM is in Public Domain.
+anything. If you like TLPM, feel free to redistribute it without any
+restrictions. TLPM is in Public Domain.
* Thanks
-Big THANK YOU to Jolanta Szelaty\\n{}ska, Staszek Wawrykiewicz, Tomek \\L{}uczak,
-Jerzy Ludwichowski and all other nice souls for all their help.
+Big THANK YOU to Jolanta Szelaty\\n{}ska, Staszek Wawrykiewicz, Tomek
+\\L{}uczak, Jerzy Ludwichowski and all other nice souls for all their help.
* Bugs
Bugs reports and comments are welcome (tlpmgui\@gust.org.pl)
@@ -128,6 +134,10 @@ Bugs reports and comments are welcome (tlpmgui\@gust.org.pl)
as in Windows
08.05.2006, 2.13 -- bugfix; changes 2.12 spoil installation from cd
04.06.2006, 2.14 -- code commented
+07.01.2007, 2.15 -- help update for TL2006
+08.01.2007, 2.16 -- bugfix; typing 'version' command was causing a program crash;
+ there is no such a command available anymore; program version
+ is displayed in the banner and command prompt
* Known issues
1. Installation from DVD is much slower than from CD. Sorry...
@@ -143,9 +153,9 @@ by grep or something.
Hardly reproducable...
* Hope for the future
-0. New TL package model
-1. Shell-specific cmd-line expansion (?)
-2. More robust and platform independent copying mechanism (DVD)",
+0. New TL package model -> versioning system -> upgrading -> via net installation
+1. Shell-specific cmd-line expansion (probably I'll give up cmdline parsing on my own)
+2. More robust and platform independent copying mechanism (especially important for DVD)",
'tlpm' =>
"USAGE:
@@ -153,7 +163,7 @@ tlpm [platforms] [-s \<source\>] [-d \<target\>] [-b \<batch\>]
DESCRIPTION:
TLPM help searching for, installing and uninstalling TeX Live packages. It
-should be used in conjunction with the TeX Live 2004-2005 CD/DVD.
+should be used in conjunction with the TeX Live 2004-2006 CD/DVD.
COMMANDS:
list list packages or files with names matching the given phrase
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.14, TeX Live Package Manager
+# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# help